artifactKeepRecent property
Number of most-recent Artifact Registry image versions the cleanup policy should keep. Defaults to 5.
Implementation
final int artifactKeepRecent;
Number of most-recent Artifact Registry image versions the cleanup policy should keep. Defaults to 5.
final int artifactKeepRecent;