deployHostingBeta property
Whether the orchestrator should create and deploy the <project>-beta
hosting site. Only meaningful when web hosting is supported.
Implementation
final bool deployHostingBeta;
Whether the orchestrator should create and deploy the <project>-beta
hosting site. Only meaningful when web hosting is supported.
final bool deployHostingBeta;