embeddedFlutterMount property
Mount path for the embedded Flutter web app inside the Jaspr host
site. Only meaningful when template is
TemplateType.arcaneJasprFlutterEmbed. Defaults to /app.
Implementation
final String embeddedFlutterMount;
Mount path for the embedded Flutter web app inside the Jaspr host
site. Only meaningful when template is
TemplateType.arcaneJasprFlutterEmbed. Defaults to /app.
final String embeddedFlutterMount;