initializeFirestore property
Whether the orchestrator should ensure the default Firestore database
exists (create on NOT_FOUND).
Implementation
final bool initializeFirestore;
Whether the orchestrator should ensure the default Firestore database
exists (create on NOT_FOUND).
final bool initializeFirestore;