setupArtifactCleanup property
Whether the orchestrator should install Artifact Registry cleanup policies for the server image. Defaults to true when setupCloudRun is true.
Implementation
final bool setupArtifactCleanup;
Whether the orchestrator should install Artifact Registry cleanup policies for the server image. Defaults to true when setupCloudRun is true.
final bool setupArtifactCleanup;