TemplateType enum
Available template types
- Inheritance
- Available extensions
Values
- arcaneTemplate → const TemplateType
- arcaneBeamer → const TemplateType
- arcaneDock → const TemplateType
- arcaneCli → const TemplateType
- arcaneJaspr → const TemplateType
- arcaneJasprDocs → const TemplateType
- arcaneJasprFlutterEmbed → const TemplateType
Properties
- canonicalPackageName → String
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get the canonical package name used in the templateno setter - description → String
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get a short description of the templateno setter - directoryName → String
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get the directory name for the template (in sibling templates/ folder)no setter - displayName → String
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get the display name for the templateno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isDartCli → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is a Dart-only CLIno setter - isFlutterApp → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is a Flutter appno setter - isJasprApp → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is a Jaspr web appno setter - isJasprDocs → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is a static Jaspr docs siteno setter - isJasprFlutterEmbed → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is the Jaspr-host + Flutter-guest embed combo.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get the template number (1-4)no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedPlatforms
→ List<
String> -
Available on TemplateType, provided by the TemplateTypeExtension extension
Get supported platforms for this templateno setter - supportsModels → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether models package can be created with this templateno setter - supportsServer → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether server app can be created with this templateno setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TemplateType> - A constant List of the values in this enum, in order of their declaration.