TemplateTypeExtension extension

Extension for template metadata

on

Properties

canonicalPackageName String

Available on TemplateType, provided by the TemplateTypeExtension extension

Get the canonical package name used in the template
no setter
description String

Available on TemplateType, provided by the TemplateTypeExtension extension

Get a short description of the template
no setter
directoryName String

Available on TemplateType, provided by the TemplateTypeExtension extension

Get the directory name for the template (in sibling templates/ folder)
no setter
displayName String

Available on TemplateType, provided by the TemplateTypeExtension extension

Get the display name for the template
no setter
isDartCli bool

Available on TemplateType, provided by the TemplateTypeExtension extension

Whether this template is a Dart-only CLI
no setter
isFlutterApp bool

Available on TemplateType, provided by the TemplateTypeExtension extension

Whether this template is a Flutter app
no setter
isJasprApp bool

Available on TemplateType, provided by the TemplateTypeExtension extension

Whether this template is a Jaspr web app
no setter
isJasprDocs bool

Available on TemplateType, provided by the TemplateTypeExtension extension

Whether this template is a static Jaspr docs site
no setter
isJasprFlutterEmbed bool

Available on TemplateType, provided by the TemplateTypeExtension extension

Whether this template is the Jaspr-host + Flutter-guest embed combo.
no setter
number int

Available on TemplateType, provided by the TemplateTypeExtension extension

Get the template number (1-4)
no setter
supportedPlatforms List<String>

Available on TemplateType, provided by the TemplateTypeExtension extension

Get supported platforms for this template
no setter
supportsModels bool

Available on TemplateType, provided by the TemplateTypeExtension extension

Whether models package can be created with this template
no setter
supportsServer bool

Available on TemplateType, provided by the TemplateTypeExtension extension

Whether server app can be created with this template
no setter

Static Methods

parse(String input) TemplateType?

Available on TemplateType, provided by the TemplateTypeExtension extension

Parse from string (number or name)