ToolCheckResult class

Summary of all tool checks

Constructors

ToolCheckResult({required List<ToolStatus> tools})

Properties

allRequiredInstalled bool
final
hashCode int
The hash code for this object.
no setterinherited
installed List<ToolStatus>
Get all installed tools
no setter
missing List<ToolStatus>
Get all missing tools
no setter
missingOptional List<ToolStatus>
final
missingRequired List<ToolStatus>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tools List<ToolStatus>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printSummary() → void
Print a summary to console
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited