ToolStatus class

Status of a CLI tool

Constructors

ToolStatus({required String name, required bool isInstalled, String? version, String? installInstructions, bool isRequired = false})
ToolStatus.installed(String name, String version, {bool isRequired = false})
Create a status for an installed tool
factory
ToolStatus.missing(String name, String installInstructions, {bool isRequired = false})
Create a status for a missing tool
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
installInstructions String?
final
isInstalled bool
final
isRequired bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited