RepositoryEnsureResult class

Result of ArtifactCleanupService.ensureRepository.

Constructors

RepositoryEnsureResult({required String repository, required String region, required RepositoryEnsureOutcome outcome, String message = ''})
const

Properties

changed bool
no setter
hashCode int
The hash code for this object.
no setterinherited
message String
Diagnostic message; empty on success.
final
outcome RepositoryEnsureOutcome
What happened.
final
region String
GCP region the repository is in (e.g. us-central1).
final
repository String
Repository name (e.g. oracular, cloud-run-source-deploy).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited