BuildStepResult class

Result of one BuildOrchestrator step.

Constructors

BuildStepResult({required BuildStepKind kind, required String label, required BuildStepStatus status, String message = '', String outputPath = ''})
const
BuildStepResult.failed(BuildStepKind kind, String label, {String reason = ''})
factory
BuildStepResult.skipped(BuildStepKind kind, String label, {String reason = ''})
factory
BuildStepResult.success(BuildStepKind kind, String label, {String outputPath = '', String message = ''})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
kind BuildStepKind
final
label String
final
message String
final
outputPath String
Absolute path to the artifact produced by this step, when applicable. Empty on skip/failure or for steps that don't produce a single discoverable artifact.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status BuildStepStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited