outputPath property
Absolute path to the artifact produced by this step, when applicable. Empty on skip/failure or for steps that don't produce a single discoverable artifact.
Implementation
final String outputPath;
Absolute path to the artifact produced by this step, when applicable. Empty on skip/failure or for steps that don't produce a single discoverable artifact.
final String outputPath;