ConfigGenerator class

Service for generating configuration files

Constructors

ConfigGenerator(SetupConfig config)

Properties

config SetupConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateAll() Future<void>
Generate all Firebase configuration files
generateFirebaseJson() Future<void>
Generate firebase.json
generateFirebaseRc() Future<void>
Generate .firebaserc
generateFirestoreIndexes() Future<void>
Generate Firestore indexes
generateFirestoreRules() Future<void>
Generate Firestore rules
generateStorageRules() Future<void>
Generate Storage rules
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited