DependencyManager class
Service for managing project dependencies
Constructors
- DependencyManager(SetupConfig config, {ProcessRunner? runner})
Properties
- config → SetupConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addDependencies(
String projectPath, List< String> packages, {bool isDev = false}) → Future<bool> - Add multiple dependencies to a project
-
addDependency(
String projectPath, String package, {bool isDev = false}) → Future< bool> - Add a dependency to a project using flutter pub add
-
dartPubGet(
String projectPath) → Future< bool> - Run dart pub get in a project
-
flutterPubGet(
String projectPath) → Future< bool> - Run flutter pub get in a project
-
getAllDependencies(
) → Future< bool> - Get dependencies for all projects with progress tracking
-
getAppDependencies(
) → Future< bool> - Get dependencies for the main app
-
getModelsDependencies(
) → Future< bool> - Get dependencies for the models package
-
getServerDependencies(
) → Future< bool> - Get dependencies for the server app
-
linkModelsToProjects(
) → Future< void> - Link models package to other projects by adding path dependency
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runAllBuildRunners(
) → Future< bool> - Run build_runner for all projects that need it with progress
-
runBuildRunner(
String projectPath) → Future< bool> - Run build_runner in a project
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited