services/docs_generator library

Classes

DocsGenerator
Generates a docs/ folder inside a created Oracular project containing quick-start, command, deployment and troubleshooting how-tos. The folder always contains an index.md with a table of contents and a permutation- aware set of pages tailored to the chosen template / Firebase / server flags.