docsDir static method
Path to the docs folder that lives at the root of the user project.
Implementation
static String docsDir(SetupConfig config) {
return p.join(config.outputDir, 'docs');
}
Path to the docs folder that lives at the root of the user project.
static String docsDir(SetupConfig config) {
return p.join(config.outputDir, 'docs');
}