BlazeStatus enum

Whether the Firebase / GCP project is on Blaze (pay-as-you-go) billing.

Inheritance
Available extensions

Values

enabled → const BlazeStatus

Project has billing enabled (Blaze plan).

notEnabled → const BlazeStatus

Project has billing disabled (Spark plan).

unknown → const BlazeStatus

Could not determine status (auth missing, gcloud not installed, no IAM permission, or unexpected output). Treated as soft-fail by callers.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BlazeStatus>
A constant List of the values in this enum, in order of their declaration.