AuthProvider enum

Identifier for a Firebase Auth provider.

Currently supported by FirebaseInitializer.enableAuthProviders: • emailPassword — auto-enabled via REST when an admin token is present • google — always a console hand-off (OAuth client config is browser-only)

Inheritance
Available extensions

Values

emailPassword → const AuthProvider

Email + password (no link / no anonymous).

google → const AuthProvider

Google federated sign-in.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String

Available on AuthProvider, provided by the AuthProviderLabel extension

Human-readable label used in CLI output.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthProvider>
A constant List of the values in this enum, in order of their declaration.