FirestoreInitResult class

Outcome of FirebaseInitializer.ensureFirestoreDatabase.

Constructors

FirestoreInitResult({required bool existed, required bool created, required String region, String message = ''})
const

Properties

changed bool
Convenience: did the initializer change anything?
no setter
created bool
We just created the default database.
final
existed bool
The default database already existed.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Diagnostic message; empty on success.
final
region String
Multi-region or regional locator (e.g. nam5, us-central1).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited