StorageInitResult class

Outcome of FirebaseInitializer.ensureStorageBucket.

Constructors

StorageInitResult({required bool existed, required bool created, required String bucketName, String message = '', bool needsFirebaseInit = false, String? getStartedUrl})
const

Properties

bucketName String
Bucket name (no gs:// prefix).
final
changed bool
no setter
created bool
We just created the default bucket.
final
existed bool
The default bucket already existed.
final
getStartedUrl String?
Console URL the user can visit to finish enabling Firebase Storage.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Diagnostic message; empty on success.
final
needsFirebaseInit bool
True when the bucket is accessible via gcloud storage but Firebase Storage itself has not yet had "Get Started" clicked in the console. Callers can prompt the user to finalize via the URL in getStartedUrl.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited