serviceAccountKeyPath property

String? get serviceAccountKeyPath

Absolute path to the service-account JSON file Oracular will use for authenticating Firebase / gcloud commands, or null when none was supplied or found.

The wizard uses this to (a) decide whether to prompt the user for a one-time IAM grant before steps that require project-management permissions, and (b) display the file path in those instructions.

Implementation

String? get serviceAccountKeyPath => _resolvedServiceAccountPath;