ApplyTargetsResult class

Outcome of HostingSiteManager.applyTargets.

Constructors

ApplyTargetsResult({required bool releaseApplied, required bool betaApplied, String message = ''})
const

Properties

betaApplied bool
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
releaseApplied bool
Whether release+beta target mappings were both written into .firebaserc.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited