ServerSetup class

Service for server setup and deployment

Constructors

ServerSetup(SetupConfig config, {ProcessRunner? runner})

Properties

config SetupConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverPath String
Get the server project path
no setter
serverServiceName String
Cloud Run service name (serverPackageName with underscores replaced by hyphens to satisfy Cloud Run naming rules).
no setter

Methods

buildDockerImage() Future<bool>
Build the server Docker image
copyServiceAccountKey() Future<void>
Copy service account key to server
deployToCloudRun({String repository = 'oracular', String region = 'us-central1'}) Future<String?>
Build, push, and deploy the server to Google Cloud Run.
generateAll() Future<void>
Generate all server files
generateDeployScript() Future<void>
Generate deployment script
generateDockerfile() Future<void>
Generate production Dockerfile
generateDockerfileDev() Future<void>
Generate development Dockerfile
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runDockerDev() Future<bool>
Run the server locally with Docker
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited