TemplateCopier class

Service for copying and customizing templates

Constructors

TemplateCopier.withPath(SetupConfig config, String templatesBasePath)
Create a TemplateCopier with a known templates path (for testing)

Properties

config SetupConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templatesBasePath String
Path to the templates directory
final

Methods

copyAll() Future<void>
Copy all templates based on config with progress tracking
copyAppTemplate() Future<void>
Copy the main app template to the output directory
copyModelsTemplate() Future<void>
Copy the models template
copyReferences() Future<void>
Copy the references folder
copyServerTemplate() Future<void>
Copy the server template
getFilesToCopy() Future<List<String>>
Get list of files that would be copied (dry run)
getTemplatePath(String templateName) String
Get the path to a specific template
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(SetupConfig config, {void onProgress(String message)?}) Future<TemplateCopier>
Create a TemplateCopier with templates ready This will download templates from GitHub if not available locally