ProjectConfigLoader class

Finds generated Oracular project configuration from common cwd locations.

Constructors

ProjectConfigLoader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

configSearchPaths(String startDir, {int maxDepth = 6}) List<String>
load({String? startDir}) Future<SetupConfig?>
printMissingConfigHelp() → void