PasswordPrompt class

Password/secret input prompts (hidden input)

Constructors

PasswordPrompt()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

askPassword(String prompt, {bool confirm = false, String? confirmPrompt}) Future<String>
Password input (hidden)
askSecret(String prompt) Future<String>
Ask for API key or secret (hidden input)