OracularProgressState class
Progress state wrapper for tracking progress
Constructors
- OracularProgressState(ProgressState _progress, int _total)
Properties
- current → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- percentage → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
no setter
Methods
-
clear(
) → void -
done(
) → void -
increment(
[int amount = 1]) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited