WizardPrompt class

Step-by-step wizard prompts

Constructors

WizardPrompt()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

printStepIndicator(int currentStep, int totalSteps, String stepName) → void
Display a step indicator
runWizard(String title, List<WizardStep> steps) Future<Map<String, dynamic>>
Run a multi-step wizard process