WizardStep class

Wizard step definition

Constructors

WizardStep({required String name, required String key, required Future execute(Map<String, dynamic> previousResults), bool required = true})

Properties

execute Future Function(Map<String, dynamic> previousResults)
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
name String
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited