SetupGuidance class
Shared setup guidance for post-create and deployment flows.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
betaHostingUrl(
String projectId) → String -
cloudRunConsoleUrl(
String projectId) → String -
createdProjectItems(
SetupConfig config) → List< String> -
firebaseAuthenticationConsoleUrl(
String projectId) → String -
firebaseFirestoreConsoleUrl(
String projectId) → String -
firebaseHostingConsoleUrl(
String projectId) → String -
firebaseOverviewUrl(
String projectId) → String -
firebaseServiceAccountUrl(
String projectId) → String -
firebaseStorageConsoleUrl(
String projectId) → String -
linkLine(
String label, String url) → String -
mainProjectLabel(
SetupConfig config) → String -
mainProjectName(
SetupConfig config) → String -
mainProjectPath(
SetupConfig config) → String -
printBetaSiteHint(
String projectId) → void -
printHostingSuccess(
SetupConfig config, {required bool beta}) → void -
printPostCreationChecklist(
SetupConfig config, {OrchestratorReport? report}) → void -
projectGuideMarkdown(
SetupConfig config) → String -
projectGuidePath(
SetupConfig config) → String -
releaseHostingUrl(
String projectId) → String -
runCommand(
SetupConfig config) → String -
supportsWebHosting(
SetupConfig config) → bool -
writeProjectGuide(
SetupConfig config) → Future< File>