description property
String
get
description
One-line description shown in wizard menus and generated docs.
Implementation
String get description {
switch (this) {
case JasprRenderMode.csr:
return 'Client-only SPA, hosted as static; fastest to build.';
case JasprRenderMode.ssg:
return 'Static pre-render at build time, SEO-friendly, hosted as static.';
case JasprRenderMode.ssr:
return 'Server-rendered at request time, deploys to Cloud Run.';
case JasprRenderMode.hybrid:
return 'Mix of static + SSR routes, deploys to Cloud Run + Hosting.';
case JasprRenderMode.embed:
return 'Jaspr static site with a Flutter web app embedded at /app.';
}
}