requiresCloudRun property
bool
get
requiresCloudRun
True for modes that produce a Cloud Run service (Dart binary) in addition to whatever ends up on Firebase Hosting.
Implementation
bool get requiresCloudRun {
return this == JasprRenderMode.ssr || this == JasprRenderMode.hybrid;
}