TemplateInfo class
Information about a template
Constructors
-
TemplateInfo({required TemplateType type, required String name, required String description, required List<
String> platforms, required bool isFlutter}) - TemplateInfo.fromType(TemplateType type)
-
factory
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFlutter → bool
-
final
- name → String
-
final
-
platforms
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → TemplateType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
all
→ List<
TemplateInfo> -
Get all available templates
no setter