TemplateTypeExtension extension
Extension for template metadata
- on
Properties
- canonicalPackageName → String
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get the canonical package name used in the templateno setter - description → String
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get a short description of the templateno setter - directoryName → String
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get the directory name for the template (in sibling templates/ folder)no setter - displayName → String
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get the display name for the templateno setter - isDartCli → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is a Dart-only CLIno setter - isFlutterApp → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is a Flutter appno setter - isJasprApp → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is a Jaspr web appno setter - isJasprDocs → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is a static Jaspr docs siteno setter - isJasprFlutterEmbed → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether this template is the Jaspr-host + Flutter-guest embed combo.no setter - number → int
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Get the template number (1-4)no setter -
supportedPlatforms
→ List<
String> -
Available on TemplateType, provided by the TemplateTypeExtension extension
Get supported platforms for this templateno setter - supportsModels → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether models package can be created with this templateno setter - supportsServer → bool
-
Available on TemplateType, provided by the TemplateTypeExtension extension
Whether server app can be created with this templateno setter
Static Methods
-
parse(
String input) → TemplateType? -
Available on TemplateType, provided by the TemplateTypeExtension extension
Parse from string (number or name)