DocsGenerator class
Generates a docs/ folder inside a created Oracular project containing
quick-start, command, deployment and troubleshooting how-tos. The folder
always contains an index.md with a table of contents and a permutation-
aware set of pages tailored to the chosen template / Firebase / server
flags.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
docsDir(
SetupConfig config) → String - Path to the docs folder that lives at the root of the user project.
-
projectBetaUrl(
SetupConfig config) → String -
write(
SetupConfig config) → Future< Directory> -
Write a complete
docs/folder. Existing files are overwritten so the guide always reflects the current configuration.