BillingCheckResult class
Detailed result of a billing check.
Constructors
- BillingCheckResult({required BlazeStatus status, String? billingAccountName, String? message})
-
const
Properties
- billingAccountName → String?
-
billingAccounts/AAAAAA-BBBBBB-CCCCCCstyle identifier when known.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isBlaze → bool
-
no setter
- message → String?
-
Human readable message describing why a check returned
unknown. Empty forenabled/notEnabled.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → BlazeStatus
-
Current billing status.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited