apiEnableUrl static method

String apiEnableUrl(
  1. String projectId,
  2. String api
)

Console URL that lets the user enable a single Google API on a project. Used in error messages so the wizard can render a clickable link.

Implementation

static String apiEnableUrl(String projectId, String api) =>
    'https://console.developers.google.com/apis/api/$api/overview?project=$projectId';