needsFirebaseInit property

bool needsFirebaseInit
final

True when the bucket is accessible via gcloud storage but Firebase Storage itself has not yet had "Get Started" clicked in the console. Callers can prompt the user to finalize via the URL in getStartedUrl.

Implementation

final bool needsFirebaseInit;