ProjectCreator class

Service for creating Flutter/Dart projects

Constructors

ProjectCreator(SetupConfig config, {ProcessRunner? runner})

Properties

config SetupConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAllProjects() Future<bool>
Create all projects based on config
createDartCli() Future<bool>
Create a Dart CLI project
createFlutterApp() Future<bool>
Create a Flutter app project
createJasprApp() Future<bool>
Create a Jaspr web app project
createModelsPackage() Future<bool>
Create a models package
createServerApp() Future<bool>
Create a server app
deleteTestFolders() Future<void>
Delete test folders from created projects
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited