ToolChecker class

Service for checking CLI tool availability

Constructors

ToolChecker({ProcessRunner? runner})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAll() Future<ToolCheckResult>
Check all tools (required and optional) with progress
checkCocoaPods() Future<ToolStatus>
Check if CocoaPods is installed (macOS only)
checkDart() Future<ToolStatus>
Check if Dart is installed and get version
checkDocker() Future<ToolStatus>
Check if Docker is installed
checkFirebase() Future<ToolStatus>
Check if Firebase CLI is installed
checkFirebaseTools() Future<ToolCheckResult>
Check tools needed for Firebase with spinner
checkFlutter() Future<ToolStatus>
Check if Flutter is installed and get version
checkFlutterFire() Future<ToolStatus>
Check if FlutterFire CLI is installed
checkGcloud() Future<ToolStatus>
Check if gcloud is installed
checkHomebrew() Future<ToolStatus>
Check if Homebrew is installed (macOS only)
checkNpm() Future<ToolStatus>
Check if npm is installed (needed for Firebase CLI)
checkRequired() Future<ToolCheckResult>
Check all required tools with spinner
checkServerTools() Future<ToolCheckResult>
Check tools needed for server deployment with spinner
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runFlutterDoctor() Future<String>
Run flutter doctor with spinner and return the output
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited