DisplayPrompt class
Display utilities (banners, boxes, lists, dividers)
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearScreen(
) → void - Clear the terminal screen
-
pressEnter(
{String message = 'Press Enter to continue...'}) → Future< void> - Press enter to continue
-
printBanner(
String title, {String? subtitle}) → void - Print a header banner
-
printConfigPreview(
Map< String, String> config, {String title = 'Configuration Preview'}) → void - Show a pretty configuration preview box
-
printDivider(
{String? title, int width = 60}) → void - Print a section divider
-
printErrorBox(
String message, {String? hint}) → void - Print an error box
-
printList(
List< String> items, {String bullet = '•'}) → void - Print a list of items with bullets
-
printNumberedList(
List< String> items) → void - Print a numbered list
-
printSuccessBox(
String message, {List< String> ? details}) → void - Print a success box