InputPrompt class
Text input prompts (strings, numbers, validation)
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
askDouble(
String question, {required double defaultValue, double? min, double? max}) → Future< double> - Ask for a double/decimal input
-
askEmail(
String question, {String? defaultValue}) → Future< String> - Ask for email input with validation
-
askInt(
String question, {required int defaultValue, int? min, int? max}) → Future< int> - Ask for a number input
-
askString(
String question, {String? defaultValue, bool validator(String)?, String? validationMessage}) → Future< String> - Ask for a string input with validation
-
askUrl(
String question, {String? defaultValue}) → Future< String> - Ask for URL input with validation