ProgressPrompt class

Progress bar prompts

Constructors

ProgressPrompt()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createProgress(int total, {String? rightPrompt, double size = 0.5}) OracularProgressState
Create a progress bar tracker
showProgress(int current, int total, String message) → void
Simple manual progress bar display
withProgress<T>(String title, List<Future<T> Function()> tasks, {List<String>? taskNames}) Future<void>
Run a list of tasks with progress tracking