fromStep property
Optional human-readable name of the step the user chose to leave; used only for log messages so the wizard can print "↩ Going back to ..."
Implementation
final String? fromStep;
Optional human-readable name of the step the user chose to leave; used only for log messages so the wizard can print "↩ Going back to ..."
final String? fromStep;