backOptionLabel constant

String const backOptionLabel

Visible menu suffix appended to selectable prompts to advertise back-navigation. Kept in one place so we can change the glyph in one edit.

Implementation

static const String backOptionLabel = '\u21B5  Back to previous step';